@@ -4,4 +4,7 @@
 # by importing them here in conftest.py they are discoverable by py.test
 # no matter how it is invoked within the source tree.
 
-from astropy.tests.pytest_plugins import *
+try:
+    from astropy.tests.pytest_plugins import *
+except Exception:  # astropy>=3.2
+    pass
