@@ -1,12 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
 An implementation of the Database API v2.0 interface to DAL VOTable responses.
-This only supports read-only access.  
+This only supports read-only access.
 """
 from __future__ import print_function, division
 
 from .query import Iter
-from astropy.extern import six
+import six
 
 if six.PY3:
     StandardError = Exception
@@ -29,7 +29,7 @@ class Warning(StandardError):
     pass
 class InterfaceError(Error):
     """
-    DB-API exception indicating an error related to the database interface 
+    DB-API exception indicating an error related to the database interface
     rather than the database itself.
     """
     pass
@@ -46,7 +46,7 @@ class DataError(DatabaseError):
     pass
 class OperationalError(DatabaseError):
     """
-    DB-API exception indicating an error related to the database's operation 
+    DB-API exception indicating an error related to the database's operation
     and not necessarily under the control of the programmer.
     """
     pass
@@ -57,7 +57,7 @@ class IntegrityError(DatabaseError):
     pass
 class InternalError(DatabaseError):
     """
-    DB-API exception indicating an internal error that might indicate that 
+    DB-API exception indicating an internal error that might indicate that
     a connection or cursor is no longer valid.
     """
     pass
@@ -81,7 +81,7 @@ class TypeObject(object):
     def id(self): return self._values[0]
 
     def __eq__(self, other):
-        if not isinstance(other, TypeObject): 
+        if not isinstance(other, TypeObject):
             return False
         if other.id in self._values:
             return True
@@ -101,14 +101,14 @@ def connect(source):
 
 class Cursor(Iter):
     """
-    A class used to walk through a query response table row by row, 
+    A class used to walk through a query response table row by row,
     accessing the contents of each record (row) of the table.  This class
     implements the Python Database API.
     """
 
     def __init__(self, results):
-        """Create a cursor instance.  The constructor is not typically called 
-        by directly applications; rather an instance is obtained from calling a 
+        """Create a cursor instance.  The constructor is not typically called
+        by directly applications; rather an instance is obtained from calling a
         DalQuery's execute().
         """
         super(Cursor, self).__init__(results)
@@ -127,7 +127,7 @@ class Cursor(Iter):
                 typ = NUMBER
             elif fld.datatype in "char unicodeChar unsignedByte".split():
                 typ = STRING
-                
+
             out.append( (name, typ) )
 
         return tuple(out)
@@ -135,10 +135,10 @@ class Cursor(Iter):
     @property
     def description(self):
         """
-        a read-only sequence of 2-item seqences.  Each seqence describes 
+        a read-only sequence of 2-item seqences.  Each seqence describes
         a column in the results, giving its name and type_code.
         """
-        return self._description 
+        return self._description
 
     @property
     def rowcount(self):
@@ -150,8 +150,8 @@ class Cursor(Iter):
     @property
     def arraysize(self):
         """
-        the number of rows that will be returned by returned by a call to 
-        fetchmany().  This defaults to 1, but can be changed.  
+        the number of rows that will be returned by returned by a call to
+        fetchmany().  This defaults to 1, but can be changed.
         """
         return self._arraysize
     @arraysize.setter
@@ -177,7 +177,7 @@ class Cursor(Iter):
         -------
         tuple :
             The response is a tuple wherein each element is the value of the
-            corresponding table field.  
+            corresponding table field.
         """
         try:
             rec = self.next()
@@ -187,7 +187,7 @@ class Cursor(Iter):
             return out
         except StopIteration:
             return None
-        
+
     def fetchmany(self, size=None):
         """Fetch the next block of rows from the query result.
 
@@ -232,9 +232,9 @@ class Cursor(Iter):
         value : str
             The number of rows to skip or the row number to position to.
         mode : str
-            Either "relative" for a relative skip (default), or "absolute" 
-            to position to a row by its absolute index within the result set 
-            (zero-indexed). 
+            Either "relative" for a relative skip (default), or "absolute"
+            to position to a row by its absolute index within the result set
+            (zero-indexed).
         """
         if mode == "absolute":
             if value > 0:
@@ -246,9 +246,8 @@ class Cursor(Iter):
 
     def close(self):
         """Close the cursor object and free all resources.  This implementation
-        does nothing.  It is provided for compliance with the Python Database 
-        API.  
+        does nothing.  It is provided for compliance with the Python Database
+        API.
         """
-        # this can remain implemented as "pass" 
+        # this can remain implemented as "pass"
         pass
-
