@@ -35,12 +35,13 @@ import re
 
 from pyvo.io.vosi.vodataservice import TableParam
 
-from astropy.extern import six
+import six
 from astropy.coordinates import SkyCoord
 from astropy.time import Time
 from astropy.units import Quantity, Unit
 
-from .query import DALResults, DALQuery, DALService, Record, mime2extension
+from .query import DALResults, DALQuery, DALService, Record
+from .mimetype import mime2extension
 from .adhoc import DatalinkResultsMixin, DatalinkRecordMixin, SodaRecordMixin
 
 from .. import samp
