@@ -2,7 +2,7 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 
-from astropy.extern import six
+import six
 
 from astropy.utils.collections import HomogeneousList
 from astropy.utils.misc import indent
