@@ -19,7 +19,7 @@ from __future__ import (absolute_import, division, print_function,
 
 import re
 
-from astropy.extern import six
+import six
 
 from astropy.utils.collections import HomogeneousList
 from astropy.utils.misc import indent
